==> pdal-1.5.0-2.tar.bz2: lib/pdal/cmake/PDALTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "pdal_boost" for configuration "Release"
set_property(TARGET pdal_boost APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_boost PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/pdal_boost.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_boost )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_boost "${_IMPORT_PREFIX}/lib/pdal_boost.lib" )

# Import target "pdal_arbiter" for configuration "Release"
set_property(TARGET pdal_arbiter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_arbiter PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/pdal_arbiter.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_arbiter )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_arbiter "${_IMPORT_PREFIX}/lib/pdal_arbiter.lib" )

# Import target "pdal_jsoncpp" for configuration "Release"
set_property(TARGET pdal_jsoncpp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_jsoncpp PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/pdal_jsoncpp.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_jsoncpp )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_jsoncpp "${_IMPORT_PREFIX}/lib/pdal_jsoncpp.lib" )

# Import target "pdal_util" for configuration "Release"
set_property(TARGET pdal_util APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_util PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/pdal_util.lib"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/pdal_util.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_util )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_util "${_IMPORT_PREFIX}/lib/pdal_util.lib" "${_IMPORT_PREFIX}/bin/pdal_util.dll" )

# Import target "pdal_plang" for configuration "Release"
set_property(TARGET pdal_plang APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_plang PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/pdal_plang.lib"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "pdalcpp;pdal_util;C:/OSGeo4W64/apps/Python36/libs/python36.lib"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/pdal_plang.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_plang )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_plang "${_IMPORT_PREFIX}/lib/pdal_plang.lib" "${_IMPORT_PREFIX}/bin/pdal_plang.dll" )

# Import target "pdalcpp" for configuration "Release"
set_property(TARGET pdalcpp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdalcpp PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/pdalcpp.lib"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "pdal_util"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "C:/OSGeo4W64/apps/gdal-dev/lib/gdal_i.lib;C:/OSGeo4W64/lib/geos_c.lib;C:/OSGeo4W64/lib/geotiff_i.lib;C:/OSGeo4W64/lib/laszip.lib;C:/OSGeo4W64/lib/libxml2.lib;C:/OSGeo4W64/lib/zlib.lib;C:/OSGeo4W64/lib/libcurl.lib;ws2_32"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/pdalcpp.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdalcpp )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdalcpp "${_IMPORT_PREFIX}/lib/pdalcpp.lib" "${_IMPORT_PREFIX}/bin/pdalcpp.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> pdal-1.6.0-3.tar.bz2: lib/pdal/cmake/PDALTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "pdal_boost" for configuration "Release"
set_property(TARGET pdal_boost APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_boost PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/pdal_boost.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_boost )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_boost "${_IMPORT_PREFIX}/lib/pdal_boost.lib" )

# Import target "pdal_arbiter" for configuration "Release"
set_property(TARGET pdal_arbiter APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_arbiter PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/pdal_arbiter.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_arbiter )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_arbiter "${_IMPORT_PREFIX}/lib/pdal_arbiter.lib" )

# Import target "pdal_kazhdan" for configuration "Release"
set_property(TARGET pdal_kazhdan APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_kazhdan PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/pdal_kazhdan.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_kazhdan )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_kazhdan "${_IMPORT_PREFIX}/lib/pdal_kazhdan.lib" )

# Import target "pdal_jsoncpp" for configuration "Release"
set_property(TARGET pdal_jsoncpp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_jsoncpp PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/pdal_jsoncpp.lib"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_jsoncpp )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_jsoncpp "${_IMPORT_PREFIX}/lib/pdal_jsoncpp.lib" )

# Import target "pdal_util" for configuration "Release"
set_property(TARGET pdal_util APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdal_util PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/pdal_util.lib"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE ""
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/pdal_util.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdal_util )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdal_util "${_IMPORT_PREFIX}/lib/pdal_util.lib" "${_IMPORT_PREFIX}/bin/pdal_util.dll" )

# Import target "pdalcpp" for configuration "Release"
set_property(TARGET pdalcpp APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(pdalcpp PROPERTIES
  IMPORTED_IMPLIB_RELEASE "${_IMPORT_PREFIX}/lib/pdalcpp.lib"
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "pdal_util"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "C:/OSGeo4W64/lib/gdal_i.lib;C:/OSGeo4W64/lib/geos_c.lib;C:/OSGeo4W64/lib/geotiff_i.lib;C:/OSGeo4W64/lib/laszip.lib;C:/OSGeo4W64/lib/libxml2.lib;C:/OSGeo4W64/lib/zlib.lib;C:/OSGeo4W64/lib/libcurl.lib;ws2_32"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/pdalcpp.dll"
  )

list(APPEND _IMPORT_CHECK_TARGETS pdalcpp )
list(APPEND _IMPORT_CHECK_FILES_FOR_pdalcpp "${_IMPORT_PREFIX}/lib/pdalcpp.lib" "${_IMPORT_PREFIX}/bin/pdalcpp.dll" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
